@@ -79,7 +79,10 @@ class MiddlewareManager():
         for name in names:
             if name in self.app.before_request_funcs:
                 for before_func in self.app.before_request_funcs[name]:
-                    rv = self.app.ensure_sync(before_func)()
+                    try:
+                        rv = self.app.ensure_sync(before_func)()
+                    except:
+                        rv = before_func()
                     if rv is not None:
                         return rv
         return None
@@ -94,4 +97,7 @@ class MiddlewareManager():
             and req.method == "OPTIONS"
         ):
             return self.app.make_default_options_response()
-        return self.app.ensure_sync(self.app.view_functions[rule.endpoint])(**req.view_args)
\ No newline at end of file
+        try:
+            return self.app.ensure_sync(self.app.view_functions[rule.endpoint])(**req.view_args)
+        except:
+            return self.app.view_functions[rule.endpoint](**req.view_args)
\ No newline at end of file
